@@ -12,7 +12,7 @@ from pykechain.utils import temp_chdir
 
 # global variable
 __mapping_dictionary = None
-__edited_one_many = list()  # type: list
+__edited_one_many: list = list()
 __references = dict()
 __attachments = list()
 
@@ -734,8 +734,14 @@ def _get_property_value(prop: AnyProperty) -> Any:
     :return: Any value
     """
     prop_value = None
-    if prop.type == PropertyType.REFERENCES_VALUE:
+    if prop.type in (PropertyType.REFERENCES_VALUE,
+                     PropertyType.ACTIVITY_REFERENCES_VALUE,
+                     PropertyType.SCOPE_REFERENCES_VALUE,
+                     PropertyType.TEAM_REFERENCES_VALUE,
+                     PropertyType.SERVICE_REFERENCES_VALUE):
         get_references()[prop] = prop.value_ids() if prop.has_value() else []
+    elif prop.type == PropertyType.USER_REFERENCES_VALUE:
+        get_references()[prop] = prop.value if prop.has_value() else []
     elif prop.type == PropertyType.ATTACHMENT_VALUE:
         get_attachments().append(prop)
     else:
