@@ -3,21 +3,20 @@ from typing import Any, List, Dict, Optional, Text, Union, Tuple, Iterable, Type
 import requests
 from jsonschema import validate
 
+from pykechain.defaults import API_EXTRA_PARAMS
 from pykechain.enums import Category
 from pykechain.exceptions import APIError, IllegalArgumentError
 from pykechain.models import Base, BaseInScope
-from pykechain.models.property2 import Property2
 from pykechain.models.input_checks import check_text, check_type
 from pykechain.models.representations.component import RepresentationsComponent
 from pykechain.models.validators import PropertyValidator
 from pykechain.models.validators.validator_schemas import options_json_schema
-from pykechain.defaults import API_EXTRA_PARAMS
 from pykechain.utils import clean_empty_values, empty
 
 T = TypeVar("T")
 
 
-class Property(BaseInScope, Property2):
+class Property(BaseInScope):
     """A virtual object representing a KE-chain property.
 
     .. versionadded: 3.0
@@ -56,8 +55,8 @@ class Property(BaseInScope, Property2):
         """Construct a Property from a json object."""
         super().__init__(json, **kwargs)
 
-        self.output = json.get('output')  # type: bool
-        self.model_id = json.get('model_id')  # type: Optional[Text]
+        self.output: bool = json.get('output')
+        self.model_id: Optional[Text] = json.get('model_id')
         self.part_id = json.get('part_id')
         self.ref = json.get('ref')
         self.type = json.get('property_type')
@@ -67,13 +66,13 @@ class Property(BaseInScope, Property2):
         self.order = json.get('order')
 
         # Create protected variables
-        self._value = json.get('value')  # type: Any
-        self._options = json.get('value_options', {})  # type: Dict
-        self._part = None  # type: Optional['Part']
-        self._model = None  # type: Optional['Property']
-        self._validators = []  # type: List[PropertyValidator]
-        self._validation_results = []  # type: List
-        self._validation_reasons = []  # type: List
+        self._value: Any = json.get('value')
+        self._options: Dict = json.get('value_options', {})
+        self._part: Optional['Part'] = None
+        self._model: Optional['Property'] = None
+        self._validators: List[PropertyValidator] = []
+        self._validation_results: List = []
+        self._validation_reasons: List = []
 
         self._representations_container = RepresentationsComponent(
             self,
@@ -395,8 +394,7 @@ class Property(BaseInScope, Property2):
         --------
         >>> front_fork = project.part('Front Fork')
         >>> color_property = front_fork.property(name='Color')
-        >>> color_property.edit(name='Shade', description='Could also be called tint, depending on mixture',
-        >>> unit='RGB')
+        >>> color_property.edit(name='Shade',description='Could also be called tint, depending on mixture',unit='RGB')
 
         >>> wheel_property_reference = self.project.model('Bike').property('Reference wheel')
         >>> wheel_model = self.project.model('Wheel')
