@@ -11,15 +11,11 @@ from pykechain.enums import (
     KEChainPages,
     ScopeRoles,
     ScopeMemberActions,
-    ScopeCategory,
-)
+    ScopeCategory, )
 from pykechain.exceptions import APIError, NotFoundError, IllegalArgumentError
-from pykechain.models.scope2 import Scope2
-from pykechain.models.service import Service, ServiceExecution
 from pykechain.models.activity import Activity
-from pykechain.models.part import Part
 from pykechain.models.base import Base
-from pykechain.models.property import Property
+from pykechain.models.context import Context
 from pykechain.models.input_checks import (
     check_text,
     check_datetime,
@@ -28,15 +24,18 @@ from pykechain.models.input_checks import (
     check_base,
     check_type,
 )
+from pykechain.models.part import Part
+from pykechain.models.property import Property
 from pykechain.models.representations import BaseRepresentation
 from pykechain.models.representations.component import RepresentationsComponent
+from pykechain.models.service import Service, ServiceExecution
 from pykechain.models.sidebar.sidebar_manager import SideBarManager
 from pykechain.models.tags import TagsMixin
 from pykechain.models.team import Team
 from pykechain.utils import parse_datetime, find, Empty, clean_empty_values, empty
 
 
-class Scope(Base, TagsMixin, Scope2):
+class Scope(Base, TagsMixin):
     """A virtual object representing a KE-chain scope.
 
     :ivar id: id of the activity
@@ -212,8 +211,8 @@ class Scope(Base, TagsMixin, Scope2):
         role = check_enum(role, ScopeRoles, "role")
         user = check_text(user, "user")
 
-        users = self._client._retrieve_users()["results"]  # type: List[Dict]
-        user_object = find(users, lambda u: u["username"] == user)  # type: Dict
+        users: List[Dict] = self._client._retrieve_users()["results"]
+        user_object: Dict = find(users, lambda u: u["username"] == user)
         if user_object is None:
             raise NotFoundError('User "{}" does not exist'.format(user))
 
@@ -282,10 +281,8 @@ class Scope(Base, TagsMixin, Scope2):
         Examples
         --------
         >>> from datetime import datetime
-        >>> project.edit(name='New project name',
-        ...              description='Changing the description just because I can',
-        ...              start_date=datetime.now(),  # naive time is interpreted as UTC time
-        ...              status=ScopeStatus.CLOSED)
+        >>> project.edit(name='New project name',description='Changing the description just because I can',
+        ... start_date=datetime.now(),status=ScopeStatus.CLOSED)
 
         If we want to provide timezone aware datetime objects we can use the 3rd party convenience library :mod:`pytz`.
         Mind that we need to fetch the timezone first and use `<timezone>.localize(<your datetime>)` to make it
@@ -301,7 +298,7 @@ class Scope(Base, TagsMixin, Scope2):
         >>> start_date_tzaware = datetime.now(pytz.utc)
         >>> mytimezone = pytz.timezone('Europe/Amsterdam')
         >>> due_date_tzaware = mytimezone.localize(datetime(2019, 10, 27, 23, 59, 0))
-        >>> project.edit(due_date=due_date_tzaware, start_date=start_date_tzaware)
+        >>> project.edit(start_date=start_date_tzaware,due_date=due_date_tzaware)
 
         To assign a scope to a team see the following example::
 
@@ -423,12 +420,12 @@ class Scope(Base, TagsMixin, Scope2):
         return self._client.create_model(parent, name, multiplicity=multiplicity)
 
     def create_model_with_properties(
-        self,
-        parent,
-        name,
-        multiplicity=Multiplicity.ZERO_MANY,
-        properties_fvalues=None,
-        **kwargs
+            self,
+            parent,
+            name,
+            multiplicity=Multiplicity.ZERO_MANY,
+            properties_fvalues=None,
+            **kwargs
     ) -> 'Part':
         """Create a model with its properties in a single API request.
 
@@ -472,11 +469,11 @@ class Scope(Base, TagsMixin, Scope2):
         return SideBarManager(scope=self, *args, **kwargs)
 
     def set_landing_page(
-        self,
-        activity: Union["Activity", KEChainPages],
-        task_display_mode: Optional[
-            SubprocessDisplayMode
-        ] = SubprocessDisplayMode.ACTIVITIES,
+            self,
+            activity: Union["Activity", KEChainPages],
+            task_display_mode: Optional[
+                SubprocessDisplayMode
+            ] = SubprocessDisplayMode.ACTIVITIES,
     ) -> None:
         """
         Update the landing page of the scope.
@@ -570,10 +567,10 @@ class Scope(Base, TagsMixin, Scope2):
     #
 
     def members(
-        self,
-        is_manager: Optional[bool] = None,
-        is_supervisor: Optional[bool] = None,
-        is_leadmember: Optional[bool] = None,
+            self,
+            is_manager: Optional[bool] = None,
+            is_supervisor: Optional[bool] = None,
+            is_leadmember: Optional[bool] = None,
     ) -> List[Dict]:
         """
         Retrieve members of the scope.
@@ -736,3 +733,42 @@ class Scope(Base, TagsMixin, Scope2):
             role=ScopeRoles.SUPERVISOR,
             user=supervisor,
         )
+
+    #
+    # Context Methods
+    #
+    def context(self, *args, **kwargs) -> Context:
+        """
+        Retrieve a context object in this scope.
+
+        See :class:`pykechain.Client.context` for available parameters.
+
+        .. versionadded:: 3.11
+
+        :return: a Context object
+        """
+        return self._client.context(*args, scope=self, **kwargs)
+
+    def contexts(self, *args, **kwargs) -> List[Context]:
+        """
+        Retrieve one or more contexts object in this scope.
+
+        See :class:`pykechain.Client.contexts` for available parameters.
+
+        .. versionadded:: 3.11
+
+        :return: a list of Context objects
+        """
+        return self._client.contexts(scope=self, **kwargs)
+
+    def create_context(self, *args, **kwargs) -> Context:
+        """
+        Create a new Context object of a ContextType in a scope.
+
+        See :class:`pykechain.Client.create_context` for available parameters.
+
+        .. versionadded:: 3.11
+
+        :return: a Context object
+        """
+        return self._client.create_context(scope=self, **kwargs)
