@@ -3,7 +3,7 @@ from .widget import Widget  # noqa: F403,F401,D104
 from .widget_models import MetapanelWidget, PropertygridWidget, UndefinedWidget, FilteredgridWidget, SupergridWidget, \
     AttachmentviewerWidget, TasknavigationbarWidget, HtmlWidget, ServiceWidget, NotebookWidget, JsonWidget, \
     MulticolumnWidget, ProgressWidget, ScopeWidget, ThirdpartyWidget, SignatureWidget, CardWidget, ServicecardWidget, \
-    DashboardWidget
+    DashboardWidget, TasksWidget, ScopemembersWidget
 from .widgets_manager import WidgetsManager
 
 __all__ = (
@@ -26,6 +26,8 @@ __all__ = (
     'CardWidget',
     'ServicecardWidget',
     'DashboardWidget',
+    'TasksWidget',
+    'ScopemembersWidget',
     'ThirdpartyWidget',
     'WidgetsManager'
 )
