@@ -546,20 +546,12 @@ class TestActivities(TestBetamax):
         initial_tags = ['tag_one', 'tag_two']
         initial_assignee = self.client.user(username="testuser")
 
-        self.task.edit(
-            name=initial_name,
-            description=initial_description,
-            start_date=initial_start_date,
-            assignees=[initial_assignee.username],
-            due_date=initial_due_date,
-            tags=initial_tags,
-        )
+        self.task.edit(name=initial_name, description=initial_description, tags=initial_tags,
+                       start_date=initial_start_date, due_date=initial_due_date, assignees=[initial_assignee.username])
 
         # Edit without mentioning values, everything should stay the same
         new_name = 'New name for task'
-        self.task.edit(
-            name=new_name
-        )
+        self.task.edit(name=new_name)
 
         # testing
         self.assertEqual(self.task.name, new_name)
@@ -571,15 +563,8 @@ class TestActivities(TestBetamax):
         self.assertEqual(self.task.tags, initial_tags)
 
         # Edit with clearing the values, name and status cannot be cleared
-        self.task.edit(
-            name=None,
-            description=None,
-            start_date=None,
-            due_date=None,
-            status=None,
-            assignees=None,
-            tags=None
-        )
+        self.task.edit(name=None, description=None, tags=None, start_date=None, due_date=None, status=None,
+                       assignees=None)
         self.task.refresh()
         self.assertEqual(self.task.name, new_name)
         self.assertEqual(self.task.description, str())
@@ -966,7 +951,6 @@ class TestActivityDownloadAsPDF(TestBetamax):
     def test_activity_share_pdf(self):
         # setUp
         test_user = self.client.user(username="testuser")
-
         activity_name = "Task - Form"
         message = "EXAMPLE_MESSAGE"
         subject = "EXAMPLE_SUBJECT"
@@ -995,3 +979,68 @@ class TestActivityDownloadAsPDF(TestBetamax):
 
         # tearDown
         notifications[0].delete()
+
+    def test_activity_share_pdf_with_from_user(self):
+        # setUp
+        test_user = self.client.user(username="anotheruser")
+        from_user = self.client.user(username="testuser")
+        activity_name = "Task - Form"
+        message = "EXAMPLE_MESSAGE"
+        subject = "EXAMPLE_SUBJECT"
+        paper_size = PaperSize.A2
+        paper_orientation = PaperOrientation.PORTRAIT
+        recipient_users = [test_user]
+
+        activity = self.project.activity(name=activity_name)
+
+        activity.share_pdf(
+            from_user=from_user,
+            subject=subject,
+            message=message,
+            recipient_users=recipient_users,
+            paper_size=paper_size,
+            paper_orientation=paper_orientation,
+            include_appendices=False,
+            include_qr_code=True,
+        )
+
+        # testing
+        notifications = self.client.notifications(
+            subject=subject, message=message, event=NotificationEvent.SHARE_ACTIVITY_PDF
+        )
+        self.assertEqual(self.client.last_response.status_code, requests.codes.ok)
+        self.assertTrue(len(notifications), 1)
+
+        # tearDown
+        notifications[0].delete()
+
+    def test_activity_share_link_with_from_user(self):
+        # setUp
+        test_user = self.client.user(username="anotheruser")
+        from_user = self.client.user(username="testuser")
+
+        activity_name = "Task - Form"
+        message = "EXAMPLE_MESSAGE"
+        subject = "EXAMPLE_SUBJECT"
+        recipient_users = [test_user]
+
+        activity = self.project.activity(name=activity_name)
+
+        activity.share_link(
+            from_user=from_user,
+            subject=subject,
+            message=message,
+            recipient_users=recipient_users,
+        )
+
+        # testing
+        notifications = self.client.notifications(
+            subject=subject,
+            message=message,
+            event=NotificationEvent.SHARE_ACTIVITY_LINK,
+        )
+        self.assertEqual(self.client.last_response.status_code, requests.codes.ok)
+        self.assertTrue(len(notifications), 1)
+
+        # tearDown
+        notifications[0].delete()
